@@ -18,12 +18,15 @@ from ecowitt2mqtt.const import (
     DATA_POINT_GLOB_BATT,
     DATA_POINT_GLOB_GUST,
     DATA_POINT_GLOB_HUMIDITY,
+    DATA_POINT_GLOB_LEAK,
     DATA_POINT_GLOB_MOISTURE,
     DATA_POINT_GLOB_PM10,
     DATA_POINT_GLOB_PM25,
     DATA_POINT_GLOB_RAIN,
     DATA_POINT_GLOB_TEMP,
+    DATA_POINT_GLOB_TF,
     DATA_POINT_GLOB_VOLT,
+    DATA_POINT_GLOB_WETNESS,
     DATA_POINT_GLOB_WIND,
     DATA_POINT_GLOB_WINDDIR,
     DATA_POINT_HEATINDEX,
@@ -38,6 +41,7 @@ from ecowitt2mqtt.const import (
     DATA_POINT_SOLARRADIATION_LUX,
     DATA_POINT_SOLARRADIATION_PERCEIVED,
     DATA_POINT_TF_CO2,
+    DATA_POINT_TOTAL_AIN,
     DATA_POINT_TOTAL_RAIN,
     DATA_POINT_UV,
     DATA_POINT_WEEKLY_RAIN,
@@ -46,7 +50,6 @@ from ecowitt2mqtt.const import (
     LOGGER,
 )
 from ecowitt2mqtt.data import ProcessedData
-from ecowitt2mqtt.errors import EcowittError
 from ecowitt2mqtt.helpers.calculator import CalculatedDataPoint
 from ecowitt2mqtt.helpers.calculator.battery import (
     BatteryStrategy,
@@ -72,6 +75,7 @@ class DeviceClass(StrEnum):
     DURATION = "duration"
     HUMIDITY = "humidity"
     ILLUMINANCE = "illuminance"
+    MOISTURE = "moisture"
     PM10 = "pm10"
     PM25 = "pm25"
     PRESSURE = "pressure"
@@ -102,12 +106,6 @@ class StateClass(StrEnum):
     TOTAL_INCREASING = "total_increasing"
 
 
-class HassError(EcowittError):
-    """Define an error related to a MQTT Discovery error."""
-
-    pass
-
-
 class DeviceType(TypedDict):
     """Define a type that represents a Home Assistant device."""
 
@@ -136,6 +134,9 @@ class HassDiscoveryPayload:
     topic: str
 
 
+AVAILABILITY_OFFLINE = "offline"
+AVAILABILITY_ONLINE = "online"
+
 DATA_POINT_BATTERY_BOOLEAN = "battery_boolean"
 DATA_POINT_BATTERY_NUMERIC = "battery_numeric"
 DATA_POINT_BATTERY_PERCENTAGE = "battery_percentage"
@@ -167,6 +168,10 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.HUMIDITY,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_GLOB_LEAK: EntityDescription(
+        device_class=DeviceClass.MOISTURE,
+        state_class=StateClass.MEASUREMENT,
+    ),
     DATA_POINT_GLOB_MOISTURE: EntityDescription(
         icon="mdi:water-percent",
         state_class=StateClass.MEASUREMENT,
@@ -187,10 +192,18 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_GLOB_TF: EntityDescription(
+        device_class=DeviceClass.TEMPERATURE,
+        state_class=StateClass.MEASUREMENT,
+    ),
     DATA_POINT_GLOB_VOLT: EntityDescription(
         device_class=DeviceClass.VOLTAGE,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_GLOB_WETNESS: EntityDescription(
+        icon="mdi:water-percent",
+        state_class=StateClass.MEASUREMENT,
+    ),
     DATA_POINT_GLOB_WIND: EntityDescription(
         icon="mdi:weather-windy",
         state_class=StateClass.MEASUREMENT,
@@ -255,6 +268,10 @@ ENTITY_DESCRIPTIONS = {
         device_class=DeviceClass.TEMPERATURE,
         state_class=StateClass.MEASUREMENT,
     ),
+    DATA_POINT_TOTAL_AIN: EntityDescription(
+        icon="mdi:water",
+        state_class=StateClass.TOTAL_INCREASING,
+    ),
     DATA_POINT_UV: EntityDescription(
         icon="mdi:weather-sunny",
         state_class=StateClass.MEASUREMENT,
@@ -275,6 +292,13 @@ STATE_CLASS_OVERRIDES = {
 }
 
 
+def get_availability_payload(data_point: CalculatedDataPoint) -> str:
+    """Get the availability payload for a data point."""
+    if data_point.value is None:
+        return AVAILABILITY_OFFLINE
+    return AVAILABILITY_ONLINE
+
+
 class HomeAssistantDiscoveryPublisher(MqttPublisher):
     """Define an MQTT publisher for the MQTT Discovery standard."""
 
@@ -285,18 +309,20 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
         self._discovery_payloads: dict[str, HassDiscoveryPayload] = {}
 
     def _generate_discovery_payload(
-        self, device: Device, key: str, data_point: CalculatedDataPoint
+        self, device: Device, payload_key: str, data_point: CalculatedDataPoint
     ) -> HassDiscoveryPayload:
         """Generate a discovery payload for an entity."""
-        platform = Platform.SENSOR
+        if isinstance(data_point.value, StrEnum):
+            platform = Platform.BINARY_SENSOR
+        else:
+            platform = Platform.SENSOR
 
         # Since batteries can be one of many different strategies, we calculate an
         # entity description at runtime:
         if data_point.data_point_key in (DATA_POINT_GLOB_BATT, DATA_POINT_GLOB_VOLT):
-            strategy = get_battery_strategy(self.ecowitt, key)
+            strategy = get_battery_strategy(self.ecowitt, payload_key)
             if strategy == BatteryStrategy.BOOLEAN:
                 data_point_key = DATA_POINT_BATTERY_BOOLEAN
-                platform = Platform.BINARY_SENSOR
             elif strategy == BatteryStrategy.NUMERIC:
                 data_point_key = DATA_POINT_BATTERY_NUMERIC
             else:
@@ -304,21 +330,19 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
         else:
             data_point_key = data_point.data_point_key
 
-        if (description := ENTITY_DESCRIPTIONS.get(data_point_key)) is None:
-            raise HassError("No entity description")
-
         if self.ecowitt.config.hass_entity_id_prefix:
-            name = f"{self.ecowitt.config.hass_entity_id_prefix}_{key}"
+            name = f"{self.ecowitt.config.hass_entity_id_prefix}_{payload_key}"
         else:
-            name = key
+            name = payload_key
 
         base_topic = (
             f"{self.ecowitt.config.hass_discovery_prefix}/{platform}/{device.unique_id}"
-            f"/{key}"
+            f"/{payload_key}"
         )
 
-        payload = self._discovery_payloads[key] = HassDiscoveryPayload(
+        payload = self._discovery_payloads[payload_key] = HassDiscoveryPayload(
             {
+                "availability_topic": f"{base_topic}/availability",
                 "device": {
                     "identifiers": [device.unique_id],
                     "manufacturer": device.manufacturer,
@@ -329,24 +353,33 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
                 "name": name,
                 "qos": 1,
                 "state_topic": f"{base_topic}/state",
-                "unique_id": f"{device.unique_id}_{key}",
+                "unique_id": f"{device.unique_id}_{payload_key}",
             },
             f"{base_topic}/config",
         )
 
-        for discovery_key, value in (
-            ("device_class", description.device_class),
-            ("entity_category", description.entity_category),
-            ("icon", description.icon),
-            ("unit_of_measurement", data_point.unit),
-        ):
-            if not value:
-                continue
-            payload.payload[discovery_key] = value
+        if data_point.unit:
+            payload.payload["unit_of_measurement"] = data_point.unit
 
-        payload.payload["state_class"] = STATE_CLASS_OVERRIDES.get(
-            key, description.state_class
-        )
+        # If we have an entity description, use it:
+        if description := ENTITY_DESCRIPTIONS.get(data_point_key):
+            for discovery_key, value in (
+                ("device_class", description.device_class),
+                ("entity_category", description.entity_category),
+                ("icon", description.icon),
+                (
+                    "state_class",
+                    STATE_CLASS_OVERRIDES.get(payload_key, description.state_class),
+                ),
+            ):
+                if not value:
+                    continue
+                payload.payload[discovery_key] = value
+        else:
+            LOGGER.debug(
+                'Missing entity description for "%s" (please report it!)',
+                payload_key,
+            )
 
         return payload
 
@@ -355,17 +388,17 @@ class HomeAssistantDiscoveryPublisher(MqttPublisher):
         processed_data = ProcessedData(self.ecowitt, data)
         publish_tasks = []
 
-        for key, data_point in processed_data.output.items():
-            try:
-                discovery_payload = self._generate_discovery_payload(
-                    processed_data.device, key, data_point
-                )
-            except HassError as err:
-                LOGGER.warning('Skipping "%s" due to error: %s', key, err)
-                continue
+        for payload_key, data_point in processed_data.output.items():
+            discovery_payload = self._generate_discovery_payload(
+                processed_data.device, payload_key, data_point
+            )
 
             for topic, payload in (
                 (discovery_payload.topic, discovery_payload.payload),
+                (
+                    discovery_payload.payload["availability_topic"],
+                    get_availability_payload(data_point),
+                ),
                 (discovery_payload.payload["state_topic"], data_point.value),
             ):
                 publish_tasks.append(
